import { createConfig } from '@redocly/openapi-core';
import openapiTS, { astToString, } from 'openapi-typescript';
import ts from 'typescript';
export async function generateSchemaTypes(schema, { silent, args, }) {
    return astToString(await openapiTS(schema, {
        transform: args.blobFromBinary ? transformFormatBinary : undefined,
        additionalProperties: args.additionalProperties,
        alphabetize: args.alphabetize,
        arrayLength: args.arrayLength,
        // contentNever: args.contentNever, // todo::add `contentNever` in new version
        defaultNonNullable: args.defaultNonNullable,
        emptyObjectsUnknown: args.emptyObjectsUnknown,
        enum: args.enum,
        excludeDeprecated: args.excludeDeprecated,
        exportType: args.exportType,
        immutable: args.immutable,
        pathParamsAsTypes: args.pathParamsAsTypes,
        redocly: await createConfig({}, { extends: ['minimal'] }),
        propertiesRequiredByDefault: args.propertiesRequiredByDefault,
        silent,
    }));
}
function transformFormatBinary(schemaObject) {
    if (schemaObject.format !== 'binary')
        return;
    return {
        schema: schemaObject.nullable
            ? ts.factory.createUnionTypeNode([
                ts.factory.createTypeReferenceNode(ts.factory.createIdentifier('Blob'), undefined),
                ts.factory.createLiteralTypeNode(ts.factory.createNull()),
            ])
            : ts.factory.createTypeReferenceNode(ts.factory.createIdentifier('Blob'), undefined),
        // questionToken will be inferred by `openapiTS`, if true, it will force `?` for parameter
        questionToken: false,
    };
}
//# sourceMappingURL=generateSchemaTypes.js.map